#
# spec file for package ppsspp
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define native_rev 52ce9c11185ddb3ca40950036d8b9926784640c0
%define lang_rev 52c757eb9b2520438e453a03e59ece4bc0001cdc
%define armips_rev a0b878fced466b71b9b78b6187038c826dec0684

Name:           ppsspp
Version:        1.0.1
Release:        3.44
Summary:        A Fast and Portable High-Level PSP Emulator
License:        GPL-2.0+
Group:          System/Emulators/Other
Url:            http://www.ppsspp.org
Source0:        https://github.com/hrydgard/ppsspp/archive/v%{version}.tar.gz
Source1:        https://github.com/hrydgard/native/archive/%{native_rev}.zip
Source2:        https://github.com/hrydgard/ppsspp-lang/archive/%{lang_rev}.zip
Source3:        https://github.com/Kingcom/armips/archive/%{armips_rev}.zip
# PATCH-FEATURE-OPENSUSE ppsspp-use-optflags.patch gber@opensuse.org -- Prevent optflags from being overridden in QMAKE_CFLAGS or QMAKE_CXXFLAGS
Patch0:         ppsspp-use-optflags.patch
# PATCH-FEATURE-OPENSUSE ppsspp-use-system-libs.patch gber@opensuse.org -- Use system libraries where possible
Patch1:         ppsspp-use-system-libs.patch
# PATCH-FIX-UPSTREAM ppsspp-fix-gcc-check.patch gber@opensuse.org -- Fix a faulty check for the gcc version
Patch2:         ppsspp-fix-gcc-check.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  unzip
BuildRequires:  gcc-c++
BuildRequires:  Mesa-devel
BuildRequires:  snappy-devel
BuildRequires:  libzip-devel
BuildRequires:  libqt5-qttools
%if 0%{?suse_version} > 1310
BuildRequires:  libqt5-linguist
%endif
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libavcodec) = 56.60.100
BuildRequires:  pkgconfig(libavformat) = 56.40.101
BuildRequires:  pkgconfig(libswscale) = 3.1.101
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# on x86 the code requires SSE2 in several places without fallbacks
ExclusiveArch:  x86_64

%description
PPSSPP is a fast and portable high-level PSP emulator which can run PSP games
on the PC in full HD resolution. It can even upscale textures that would
otherwise be too blurry as they were made for the small screen of the original
PSP.

%prep
%setup -q -a1 -a2 -a3

rm -rf native
ln -s native-%{native_rev} native
rm -rf lang
ln -s ppsspp-lang-%{lang_rev} lang
rm -rf ext/armips
ln -s ../armips-%{armips_rev} ext/armips

%patch0 -p1
%patch1 -p1
%patch2 -p1

# ensure system libraries are used instead
rm -rf ext/zlib
rm -rf ext/snappy
rm -rf native/ext/libzip

%build
export PATH=%_libqt5_bindir:$PATH
rm -rfv ffmpeg
mkdir -vp ffmpeg/linux/x86_64
ln -sfvbn /usr/include/ffmpeg ffmpeg/linux/x86_64/include
pkg-config --cflags-only-I libavformat
mkdir build
cd build
%qmake5 \
    "QMAKE_CFLAGS=${CFLAGS}" \
    "QMAKE_CXXFLAGS=${CXXFLAGS}" \
    'CONFIG+=release' \
    ../Qt/PPSSPPQt.pro
%make_jobs

%install
install -D -p -m 755 build/ppsspp %{buildroot}%{_bindir}/ppsspp

for icon in assets/unix-icons/hicolor/*/*/*.png; do
    install -D -p -m 644 "${icon}" \
        "%{buildroot}%{_datadir}/icons/${icon#assets/unix-icons}"
done

%suse_update_desktop_file -c %{name} PPSSPP 'PSP Emulator' %{name} %{name} System Emulator

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc README.md LICENSE.TXT
%{_bindir}/%{name}
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/applications/%{name}.desktop

%changelog
* Mon May  4 2015 gber@opensuse.org
- update to version 1.0.1
  - Bugfixes like the save state scroll issue, cosmetic issues like
    overscroll
  - Some cheat code bugfixes
  - Adler32 and Mersenne Twister modules added (fixes some obscure
    games)
  - Fix for Jak & Daxter slowdown
  - Graphics hack for Phantasy Star Portable 2 for Direct3D9
  - Fix compatibility with some PowerVR devices broken since
    v0.9.5-959-g4998044
* Sun Feb 22 2015 gber@opensuse.org
- update to version 1.0
  - many, many bug fixes in JIT and elsewhere, improving
    compatibility
  - proper fix for Zenfone and related devices
  - Direct3D 9 supported as a rendering backend on Windows, helps
    on old GPUs and can be faster than OpenGL in many cases
  - you can now create specific configs per game
  - FPU rounding modes much better supported, fixes the Peace
    Walker boss that was undefeatable. NOTE: This breaks saves in
    Gods Eater - you must turn off the better rounding, load your
    save game, turn it on and save.
  - the JIT now uses SSE on x86, improving speed considerably. This
    does not affect ARM devices, that's for the next version or
    two.
  - improved audio output code on both Windows and Android,
    reducing audio latency on Windows and on some Android systems
  - FFMPEG upgraded, fixed some music hangs ("GHA phase shifts")
  - some Ad Hoc improvements, coldbird.net is now default adhoc
    server. Ad Hoc still unfinished and hard to use.
  - graphics fixes: Bezier/spline drawing fixes, vertex position
    fixes, DanganRonpa on Adreno fixed, flat shading fixed, vertex
    cache improved, some PowerVR blockiness issues fixed, screen
    scaling filter added, Google Cardboard support
  - simulate UMD speed better, fixing hangs in several games
  - more Atrac3 fixes, fixing hangs
  - somewhat better disk full handling
  - fixes to dynamic unloading of code, fixing problems in GEB and
    TRM 2/3
  - updated to SDL2 where applicable (Linux, Mac)
  - some new features, like analog/dpad-swap hotkey, graphics hack
    for Phantasy Star, show last bit of debug log in dev tools, etc
  - no more need for MSVCRT DLLs on Windows
* Wed Oct 22 2014 gber@opensuse.org
- update to version 0.9.9.1
  - see the included README.md for a detailed list of changes
- build Qt5 frontend
- use system ffmpeg
- add ppsspp-use-optflags.patch to prevent optflags from being
  overridden in QMAKE_CFLAGS or QMAKE_CXXFLAGS
- add ppsspp-use-system-libs.patch to use system snappy and libzip
- add ppsspp-fix-gcc-check.patch in order to remove a faulty check
  for the gcc version
- generate desktop file
- properly update desktop database and icon cache
- build exclusively on x86_64, the code requires SSE2 in several
  places without fallbacks
* Fri Jul 26 2013 i@margueirte.su
- initial version 20130726
